@@ -810,6 +810,15 @@ def test_intersect(
             UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
         ),
+        (
+            UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+            UnionConstraint(
+                ExtraConstraint("extra1"),
+                ExtraConstraint("extra2"),
+                ExtraConstraint("extra3"),
+            ),
+            UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+        ),
         (
             UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             UnionConstraint(ExtraConstraint("extra2"), ExtraConstraint("extra1")),
@@ -920,6 +929,11 @@ def test_intersect(
             UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             EmptyConstraint(),
         ),
+        (
+            ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+            UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+            ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+        ),
     ],
 )
 def test_intersect_extra(
@@ -1115,20 +1129,12 @@ def test_intersect_extra(
         (
             UnionConstraint(Constraint("win32"), Constraint("linux")),
             MultiConstraint(Constraint("win32", "!="), Constraint("darwin", "!=")),
-            UnionConstraint(
-                Constraint("win32"),
-                Constraint("linux"),
-                MultiConstraint(Constraint("win32", "!="), Constraint("darwin", "!=")),
-            ),
+            Constraint("darwin", "!="),
         ),
         (
             UnionConstraint(Constraint("win32"), Constraint("linux")),
             MultiConstraint(Constraint("win32", "!="), Constraint("linux", "!=")),
-            UnionConstraint(
-                Constraint("win32"),
-                Constraint("linux"),
-                MultiConstraint(Constraint("win32", "!="), Constraint("linux", "!=")),
-            ),
+            AnyConstraint(),
         ),
         (
             MultiConstraint(Constraint("win32", "!="), Constraint("linux", "!=")),
@@ -1499,34 +1505,48 @@ def test_union(
         (
             UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             ExtraMultiConstraint(
-                ExtraConstraint("extra1", "!="), ExtraConstraint("extra3", "!=")
+                ExtraConstraint("extra3", "!="), ExtraConstraint("extra4", "!=")
             ),
             UnionConstraint(
                 ExtraConstraint("extra1"),
                 ExtraConstraint("extra2"),
                 ExtraMultiConstraint(
-                    ExtraConstraint("extra1", "!="), ExtraConstraint("extra3", "!=")
+                    ExtraConstraint("extra3", "!="), ExtraConstraint("extra4", "!=")
                 ),
             ),
         ),
+        (
+            UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+            ExtraMultiConstraint(
+                ExtraConstraint("extra1", "!="), ExtraConstraint("extra3", "!=")
+            ),
+            UnionConstraint(
+                ExtraConstraint("extra1"),
+                ExtraConstraint("extra2"),
+                ExtraConstraint("extra3", "!="),
+            ),
+        ),
         (
             UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             ExtraMultiConstraint(
                 ExtraConstraint("extra1", "!="), ExtraConstraint("extra2", "!=")
             ),
-            UnionConstraint(
-                ExtraConstraint("extra1"),
-                ExtraConstraint("extra2"),
-                ExtraMultiConstraint(
-                    ExtraConstraint("extra1", "!="), ExtraConstraint("extra2", "!=")
-                ),
-            ),
+            AnyConstraint(),
         ),
         (
             ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
         ),
+        (
+            ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+            ExtraMultiConstraint(
+                ExtraConstraint("extra1"),
+                ExtraConstraint("extra2"),
+                ExtraConstraint("extra3"),
+            ),
+            ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+        ),
         (
             ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
             ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra3")),
@@ -1575,6 +1595,11 @@ def test_union(
                 ),
             ),
         ),
+        (
+            UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+            ExtraMultiConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra3")),
+            UnionConstraint(ExtraConstraint("extra1"), ExtraConstraint("extra2")),
+        ),
     ],
 )
 def test_union_extra(
