@@ -11,8 +11,12 @@ from packaging.utils import canonicalize_name
 
 from poetry.core.constraints.version import parse_constraint
 from poetry.core.factory import Factory
+from poetry.core.packages.dependency import Dependency
+from poetry.core.packages.directory_dependency import DirectoryDependency
+from poetry.core.packages.file_dependency import FileDependency
 from poetry.core.packages.url_dependency import URLDependency
 from poetry.core.packages.vcs_dependency import VCSDependency
+from poetry.core.pyproject.tables import BuildSystem
 from poetry.core.utils._compat import tomllib
 from poetry.core.version.markers import SingleMarker
 
@@ -20,10 +24,6 @@ from poetry.core.version.markers import SingleMarker
 if TYPE_CHECKING:
     from pytest import LogCaptureFixture
 
-    from poetry.core.packages.dependency import Dependency
-    from poetry.core.packages.directory_dependency import DirectoryDependency
-    from poetry.core.packages.file_dependency import FileDependency
-
 
 fixtures_dir = Path(__file__).parent / "fixtures"
 
@@ -160,9 +160,12 @@ def complete_legacy_duplicate_warnings() -> list[str]:
     ]
 
 
-@pytest.mark.parametrize("new_format", [False, True])
-def test_create_poetry(new_format: str) -> None:
-    project = "sample_project_new" if new_format else "sample_project"
+@pytest.mark.parametrize(
+    "project", ["sample_project", "sample_project_new", "sample_project_dynamic"]
+)
+def test_create_poetry(project: str) -> None:
+    new_format = project == "sample_project_new"
+    dynamic = project == "sample_project_dynamic"
     poetry = Factory().create_poetry(fixtures_dir / project)
 
     assert poetry.is_package_mode
@@ -219,7 +222,9 @@ def test_create_poetry(new_format: str) -> None:
     assert tomlkit_for_locking.develop
 
     requests = dependencies["requests"]
-    assert requests.pretty_constraint == (">=2.18,<3.0" if new_format else "^2.18")
+    assert requests.pretty_constraint == (
+        ">=2.18,<3.0" if new_format or dynamic else "^2.18"
+    )
     assert not requests.is_vcs()
     assert requests.allows_prereleases() is None
     assert requests.is_optional()
@@ -354,20 +359,29 @@ def test_create_poetry_with_packages_and_includes() -> None:
     package = poetry.package
 
     assert package.packages == [
-        {"include": "extra_dir/**/*.py"},
-        {"include": "extra_dir/**/*.py"},
-        {"include": "my_module.py"},
-        {"include": "package_with_include"},
-        {"include": "tests", "format": "sdist"},
+        {"include": "extra_dir/**/*.py", "format": ["sdist", "wheel"]},
+        {"include": "extra_dir/**/*.py", "format": ["sdist", "wheel"]},
+        {"include": "my_module.py", "format": ["sdist", "wheel"]},
+        {"include": "package_with_include", "format": ["sdist", "wheel"]},
+        {"include": "tests", "format": ["sdist"]},
         {"include": "for_wheel_only", "format": ["wheel"]},
-        {"include": "src_package", "from": "src"},
-        {"include": "from_to", "from": "etc", "to": "target_from_to"},
-        {"include": "my_module_to.py", "to": "target_module"},
+        {"include": "src_package", "from": "src", "format": ["sdist", "wheel"]},
+        {
+            "include": "from_to",
+            "from": "etc",
+            "to": "target_from_to",
+            "format": ["sdist", "wheel"],
+        },
+        {
+            "include": "my_module_to.py",
+            "to": "target_module",
+            "format": ["sdist", "wheel"],
+        },
     ]
 
     assert package.include == [
         {"path": "extra_dir/vcs_excluded.py", "format": ["sdist", "wheel"]},
-        {"path": "notes.txt"},
+        {"path": "notes.txt", "format": ["sdist"]},
     ]
 
 
@@ -407,6 +421,14 @@ def test_create_poetry_with_license_type_file(license_type: str) -> None:
     assert poetry.package.license.id == license_content
 
 
+def test_create_poetry_fails_with_missing_license_file() -> None:
+    project_dir = fixtures_dir / "missing_license_file"
+    with pytest.raises(FileNotFoundError) as e:
+        Factory().create_poetry(project_dir)
+
+    assert str((project_dir / "LICENSE").absolute()) in str(e.value)
+
+
 @pytest.mark.parametrize(
     ("requires_python", "python", "expected_versions", "expected_constraint"),
     [
@@ -611,6 +633,18 @@ def test_validate_strict_dynamic_warnings() -> None:
     }
 
 
+def test_validate_local_version(tmp_path: Path) -> None:
+    project = tmp_path / "local_version.toml"
+    project.write_text(
+        """[project]\nname = "local-version"\nversion = "0.5.0+LOCAL.123A"\n""",
+        encoding="utf-8",
+    )
+    with project.open("rb") as f:
+        content = tomllib.load(f)
+
+    assert Factory.validate(content) == {"errors": [], "warnings": []}
+
+
 def test_validate_fails() -> None:
     complete = fixtures_dir / "complete.toml"
     with complete.open("rb") as f:
@@ -720,7 +754,7 @@ def test_validate_dependencies_non_package_mode(with_project_section: bool) -> N
             (
                 "[tool.poetry.dependencies] is set but [project.dependencies] is "
                 "not and 'dependencies' is not in [project.dynamic]. You should "
-                "either migrate [tool.poetry.depencencies] to "
+                "either migrate [tool.poetry.dependencies] to "
                 "[project.dependencies] (if you do not need Poetry-specific "
                 "features) or add [project.dependencies] in addition to "
                 "[tool.poetry.dependencies] or add 'dependencies' to "
@@ -962,3 +996,79 @@ def test_all_classifiers_unique_even_if_classifiers_is_duplicated() -> None:
         "Programming Language :: Python :: 3.13",
         "Topic :: Software Development :: Build Tools",
     ]
+
+
+@pytest.mark.parametrize(
+    ("project", "expected"),
+    [
+        ("sample_project", set(BuildSystem().dependencies)),
+        (
+            "project_with_build_system_requires",
+            {
+                Dependency.create_from_pep_508("poetry-core"),
+                Dependency.create_from_pep_508("Cython (>=0.29.6,<0.30.0)"),
+            },
+        ),
+    ],
+)
+def test_poetry_build_system_dependencies_from_fixtures(
+    project: str, expected: set[Dependency]
+) -> None:
+    poetry = Factory().create_poetry(fixtures_dir / project)
+    assert set(poetry.build_system_dependencies) == expected
+
+
+SAMPLE_PROJECT_DIRECTORY = fixtures_dir / "sample_project"
+SIMPLE_PROJECT_WHEEL = (
+    fixtures_dir
+    / "simple_project"
+    / "dist"
+    / "simple_project-1.2.3-py2.py3-none-any.whl"
+)
+
+
+@pytest.mark.parametrize(
+    ("requires", "expected"),
+    [
+        (BuildSystem().requires, set(BuildSystem().dependencies)),
+        (["poetry-core>=2.0.0"], {Dependency("poetry-core", ">=2.0.0")}),
+        (["****invalid****"], set()),
+        (
+            ["hatch", "numpy ; sys_platform == 'win32'"],
+            {
+                Dependency("hatch", "*"),
+                Dependency.create_from_pep_508("numpy ; sys_platform == 'win32'"),
+            },
+        ),
+        (
+            [SAMPLE_PROJECT_DIRECTORY.as_posix()],
+            {
+                DirectoryDependency(
+                    SAMPLE_PROJECT_DIRECTORY.name, SAMPLE_PROJECT_DIRECTORY
+                )
+            },
+        ),
+        (
+            [SIMPLE_PROJECT_WHEEL.as_posix()],
+            {FileDependency(SIMPLE_PROJECT_WHEEL.name, SIMPLE_PROJECT_WHEEL)},
+        ),
+    ],
+)
+def test_poetry_build_system_dependencies(
+    requires: list[str], expected: set[Dependency], temporary_directory: Path
+) -> None:
+    pyproject_toml = temporary_directory / "pyproject.toml"
+    build_system_requires = ", ".join(f'"{require}"' for require in requires)
+    content = f"""[project]
+name = "my-package"
+version = "1.2.3"
+
+[build-system]
+requires = [{build_system_requires}]
+build-backend = "some.api.we.do.not.care.about"
+
+"""
+    pyproject_toml.write_text(content, encoding="utf-8")
+    poetry = Factory().create_poetry(temporary_directory)
+
+    assert set(poetry.build_system_dependencies) == expected
